declare namespace qg.asdk {//17玩 minigame vivo oppo

	
    interface roleData {
        playerid: string;
        playerlevel: string;
		servername:string;
		serverid:string;
		playername:string;
	};
	
	interface orderData {
        callbackurl: string;
        paymoney: string;
		custominfo?:string;
		customorderid:string;
		productdesc:string;
		productfeecode?:string;
	};
      

	function asdkInit(callBack:Function);
	function asdkLogin(callBack:Function);
	function asdkSendRole(playerinfo:roleData,callBack:Function);
	function asdkPay(payinfo:orderData,callBack:Function);
	function asdkCreateIcon(callBack:Function);
	function asdkRewardedAd(gginfo:string,callBack:Function);
	function asdkQuit();
	
	
}